"use client";
import HeaderRight from "@/components/Header/HeaderRight";
import clsx from "clsx";
import { FC, memo, ReactNode } from "react";
import HeaderTitle from "./HerderTitle";
import styles from "./style.module.scss";
/**
 * @description HeaderProps
 * @param {boolean} headerPlaceholder 是否展示展位元素
 * @param {() => ReactNode} headerRender 自定义渲染
 */
export interface HeaderProps {
    headerPlaceholder?: boolean;
    headerRender?: () => ReactNode;
    menuHandler?: () => void;
    menuRender?: () => ReactNode;
}

const cs = clsx(["iconfont icon-gengduo", styles.menu]);

const DefaultHeader: FC<HeaderProps> = (props) => {
    const { menuHandler, menuRender } = props;
    return (
        <div className={styles.headerMain}>
            <div className={styles.headerLeft} onClick={menuHandler}>
                {(menuRender && menuRender()) ?? <div className={cs}></div>}
            </div>
            <HeaderTitle />
            <HeaderRight />
        </div>
    );
};

const Header: FC<HeaderProps> = (props) => {
    const { headerPlaceholder = true, headerRender, ...other } = props;
    const cs = clsx({
        [styles.placeholder]: headerPlaceholder,
    });
    return (
        <header className={cs}>
            <div className={styles.headerWrap}>
                {headerRender ? headerRender() : <DefaultHeader {...other} />}
            </div>
        </header>
    );
};
export default memo(Header);
